@@ -1,14 +1,14 @@
 /*
  *
- * 
- * Copyright (C) 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2010, 2011, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
@@ -18,36 +18,37 @@
 #include <string.h>
 #include <sys/statvfs.h>
 
-#include <QtGui>
+#include <QByteArray>
+#include <QString>
 
 #include "misc.h"
 
 
 // Gets basic stats on mounted filesystems like amount used up.
 
-FSData get_fs_data(const QString path){
+FSData get_fs_data(const QString path)
+{
 
     struct statvfs buff;
     const QByteArray path_qba = path.toLocal8Bit();
     const int error = statvfs(path_qba.data(), &buff);
- 
+
     FSData fs_data;
 
-    if(error){
+    if (error) {
         fs_data.block_size = -1;
         fs_data.size = -1;
         fs_data.used = -1;
-    }
-    else{
+    } else {
         const long long block_size = buff.f_bsize;
         const long long frag_size  = buff.f_frsize;
         const long long total_blocks = (frag_size * buff.f_blocks) / block_size;
 
-        fs_data.block_size = block_size; 
+        fs_data.block_size = block_size;
         fs_data.size = total_blocks;
         fs_data.used = total_blocks - buff.f_bavail;
     }
-    
+
     return fs_data;
 }
 
