@@ -1,14 +1,14 @@
 /*
  *
- * 
- * Copyright (C) 2009, 2010, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
@@ -16,35 +16,42 @@
 #define KVPMCONFIGDIALOG_H
 
 #include <KConfigDialog>
-#include <KConfigSkeleton>
-#include <KColorButton>
-#include <KEditListBox>
-#include <KPageWidgetItem>
-#include <KTabWidget>
 
-#include <QColor>
-#include <QCheckBox>
-#include <QGroupBox>
-#include <QRadioButton>
-#include <QStringList>
-#include <QSpinBox>
-#include <QTableWidget>
-#include <QWidget>
+class KConfigSkeleton;
+class KColorButton;
+class KEditListWidget;
+
+class QGroupBox;
+class QLabel;
+class QStackedWidget;
+class QString;
+class QTableWidget;
+class QTabWidget;
+class QWidget;
 
 class ExecutableFinder;
 
 
 class KvpmConfigDialog: public KConfigDialog
 {
-Q_OBJECT
+    Q_OBJECT
 
     QTableWidget     *m_executables_table;
-    KEditListBox     *m_edit_list;
+    KEditListWidget  *m_edit_list;
     KConfigSkeleton  *m_skeleton;
     ExecutableFinder *m_executable_finder;
+    QStackedWidget   *m_color_stack = nullptr;
+
+    KColorButton *m_primary_button = nullptr;
+    KColorButton *m_logical_button = nullptr;
+    QLabel *m_primary_label = nullptr;
+    QLabel *m_logical_label = nullptr;
 
     QTabWidget *generalPage();
     QWidget    *colorsPage();
+    QWidget    *fsColors();
+    QWidget    *typeColors();
+    QWidget    *otherColors();
     QTabWidget *programsPage();
     QGroupBox *allGroup();
     QGroupBox *deviceGroup();
@@ -58,11 +65,12 @@ Q_OBJECT
     void fillExecutablesTable();
 
 public:
-    KvpmConfigDialog( QWidget *parent, const QString name, KConfigSkeleton *const skeleton, ExecutableFinder *const executableFinder );
+    KvpmConfigDialog(QWidget *parent, const QString name, KConfigSkeleton *const skeleton, ExecutableFinder *const executableFinder);
     ~KvpmConfigDialog();
 
 public slots:
     void updateSettings();
+    void showOtherButtons(int index);
 
 };
 
