@@ -1,39 +1,41 @@
 /*
  *
- * 
- * Copyright (C) 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2010, 2011, 2012, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
 #ifndef MAINTABWIDGET_H
 #define MAINTABWIDGET_H
 
-#include <QIcon>
+#include <QWidget>
 #include <QStringList>
-#include <KTabWidget>
+
+class QIcon;
+class QTabWidget;
 
 class VolumeGroupTab;
 class DeviceTab;
 
 class MainTabWidget : public QWidget
 {
-Q_OBJECT
+    Q_OBJECT
 
     QStringList m_unmunged_text;    // Tab labels without amperands
-    KTabWidget *m_tab_widget;
+    QTabWidget *m_tab_widget;
     QList<VolumeGroupTab *>  m_vg_tabs;
 
- signals:
-    void currentIndexChanged();
+signals:
+    void currentIndexChanged(int index);
 
- public:
+public:
     MainTabWidget(QWidget *parent = 0);
     QString getUnmungedText(const int index);
     void appendVolumeGroupTab(VolumeGroupTab *const page, const QIcon &icon, const QString &label);
@@ -44,9 +46,6 @@ Q_OBJECT
     int getCurrentIndex();
     VolumeGroupTab *getVolumeGroupTab(const int index);
     void setIcon(const int index, const QIcon &icon);
- 
- public slots:
-    void indexChanged(int index);
 
 };
 
