@@ -1,14 +1,14 @@
 /*
  *
- * 
- * Copyright (C) 2008, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2008, 2011, 2012, 2013, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
@@ -18,7 +18,7 @@
 #include <mntent.h>
 #include <stdio.h>
 
-#include <QtGui>
+#include <QString>
 
 #include "logvol.h"
 #include "volgroup.h"
@@ -41,10 +41,10 @@ MountEntry::MountEntry(MountEntry *const copy, QObject *parent) : QObject(parent
 
 MountEntry::MountEntry(mntent *const entry, QObject *parent) : QObject(parent)
 {
-    m_device_name     = QString( entry->mnt_fsname ).trimmed();
-    m_mount_point     = QString( entry->mnt_dir ).trimmed();
-    m_filesystem_type = QString( entry->mnt_type ).trimmed();
-    m_mount_options   = QString( entry->mnt_opts ).trimmed();
+    m_device_name     = QString(entry->mnt_fsname).trimmed();
+    m_mount_point     = QString(entry->mnt_dir).trimmed();
+    m_filesystem_type = QString(entry->mnt_type).trimmed();
+    m_mount_options   = QString(entry->mnt_opts).trimmed();
 
     m_major = -1;
     m_minor = -1;
@@ -54,7 +54,7 @@ MountEntry::MountEntry(mntent *const entry, QObject *parent) : QObject(parent)
 
 MountEntry::MountEntry(const QString mountinfo, const int major, const int minor, QObject *parent) : QObject(parent)
 {
-    m_mount_point     = mountinfo.section(' ', 4, 4);
+    m_mount_point     = mountinfo.section(' ', 4, 4).replace("\\040", " ");
     m_mount_options   = mountinfo.section(' ', 5, 5);
     m_filesystem_type = mountinfo.section(' ', 6, 6);
     m_device_name     = mountinfo.section(' ', 8, 8);
@@ -62,10 +62,13 @@ MountEntry::MountEntry(const QString mountinfo, const int major, const int minor
 
     m_major = major;
     m_minor = minor;
-
     m_mount_position = 0;
 }
 
+MountEntry::~MountEntry()
+{
+}
+
 QString MountEntry::getDeviceName()
 {
     return m_device_name;
@@ -110,4 +113,4 @@ int MountEntry::getMinorNumber()
 void MountEntry::setMountPosition(const int pos)
 {
     m_mount_position = pos;
-}    
+}
