@@ -1,14 +1,14 @@
 /*
  *
- * 
- * Copyright (C) 2009, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2009, 2011, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
@@ -16,7 +16,6 @@
 #ifndef PARTREMOVE_H
 #define PARTREMOVE_H
 
-#include <QStringList>
 
 class StoragePartition;
 
