@@ -1,21 +1,26 @@
 /*
  *
- * 
- * Copyright (C) 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2011, 2012, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
 
 #include "progressbox.h"
 
-#include <QtGui>
+#include <QApplication>
+
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QProgressBar>
+#include <QString>
 
 
 ProgressBox::ProgressBox(QWidget *parent) : QFrame(parent)
@@ -34,36 +39,49 @@ ProgressBox::ProgressBox(QWidget *parent) : QFrame(parent)
 
 void ProgressBox::setText(const QString text)
 {
-    show();
+    hide();
 
-    if( !text.isEmpty() )
+    if (!text.isEmpty())
         m_message->setText(text + " >>");
     else
         m_message->clear();
+
+    show();
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 }
 
 void ProgressBox::setRange(const int start, const int end)
 {
-    show();
+    hide();
 
     m_progressbar->setRange(start, end);
     m_message->clear();
+
+    show();
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+
 }
 
 void ProgressBox::setValue(const int value)
 {
-    show();
+    hide();
 
     m_progressbar->setValue(value);
-    if( value >= m_progressbar->maximum() )
+    if (value >= m_progressbar->maximum())
         m_message->clear();
+
+    show();
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 }
 
 void ProgressBox::reset()
 {
-    show();
+    hide();
 
     m_progressbar->setRange(0, 1);
     m_progressbar->setValue(1);
     m_message->clear();
+
+    show();
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 }
