@@ -1,24 +1,23 @@
 /*
  *
- * 
- * Copyright (C) 2009, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2009, 2011, 2012, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
 
 #include "pvextend.h"
 
-#include <KLocale>
 #include <KMessageBox>
 
-#include <QtGui>
+#include <QStringList>
 
 #include "processprogress.h"
 #include "storagepartition.h"
@@ -26,14 +25,14 @@
 
 bool pv_extend(QString path)
 {
-    QStringList arguments; 
+    QStringList arguments;
 
-    arguments << "pvresize" 
+    arguments << "pvresize"
               << path;
 
     ProcessProgress pv_grow(arguments);
 
-    if( pv_grow.exitCode() )
+    if (pv_grow.exitCode())
         return false;
     else
         return true;
