@@ -1,14 +1,14 @@
 /*
  *
- * 
- * Copyright (C) 2008, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2008, 2010, 2011, 2012, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
@@ -25,13 +25,12 @@ class PVProperties : public QWidget
 {
     PhysVol *m_pv;
 
-    QList<LVSegmentExtent *> sortByExtent();
     QFrame *buildMdaBox();
     QFrame *buildLvBox();
     QFrame *buildUuidBox();
 
- public:
-    explicit PVProperties(PhysVol *const volume, QWidget *parent = 0);
+public:
+    explicit PVProperties(PhysVol *const volume, QWidget *parent = nullptr);
 
 };
 
