@@ -1,21 +1,21 @@
 /*
  *
- * 
- * Copyright (C) 2009, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2009, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
 #ifndef PVREDUCE_H
 #define PVREDUCE_H
 
-#include <QString>
+class QString;
 
 
 long long pv_reduce(QString path, long long new_size);
