@@ -1,49 +1,49 @@
 /*
  *
- * 
- * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2008, 2011, 2012, 2013, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
 #ifndef UNMOUNT_H
 #define UNMOUNT_H
 
-#include <KDialog>
-#include <QStringList>
-#include <QList>
+
+
+#include "mounttables.h"
+#include "kvpmdialog.h"
+
 
 class LogVol;
-class MountEntry;
 class NoMungeCheck;
 class StoragePartition;
 
 
-class UnmountDialog : public KDialog
+class UnmountDialog : public KvpmDialog
 {
-Q_OBJECT
+    Q_OBJECT
 
-    bool m_bailout;
     bool m_single;
     QString m_mp;
     QList<NoMungeCheck *> m_check_list; // one check box for each mount point
- 
- public:
+
+public:
     UnmountDialog(StoragePartition *const partition, QWidget *parent = NULL);
     UnmountDialog(LogVol *const volume, QWidget *parent = NULL);
-    void buildDialog(QString const device, const QList<MountEntry *> entries);
+    void buildDialog(QString const device, const MountList entries);
     bool bailout();
 
- private slots:   
+private slots:
     void resetOkButton();
-    void commitChanges();
- 
+    void commit();
+
 };
 
 
