@@ -1,14 +1,14 @@
 /*
  *
- * 
- * Copyright (C) 2008, 2009, 2010, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
+ *
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2016 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License,  version 3, as 
+ * it under the terms of the GNU General Public License,  version 3, as
  * published by the Free Software Foundation.
- * 
+ *
  * See the file "COPYING" for the exact licensing terms.
  */
 
@@ -16,13 +16,11 @@
 #ifndef VGTREE_H
 #define VGTREE_H
 
-#include <KMenu>
 
-#include <QPoint>
-#include <QList>
-#include <QStringList>
 #include <QTreeWidget>
-#include <QTreeWidgetItem>
+
+class QPoint;
+class QTreeWidgetItem;
 
 
 class LogVol;
@@ -31,7 +29,7 @@ class VolGroup;
 
 class VGTree : public QTreeWidget
 {
-Q_OBJECT
+    Q_OBJECT
 
     VolGroup *m_vg;
     bool m_init;        // is this the initial building of the tree or a reload?
@@ -48,10 +46,13 @@ public:
     VGTree(VolGroup *const group);
     void loadData();
 
-private slots:    
+private slots:
     void popupContextMenu(QPoint point);
     void adjustColumnWidth(QTreeWidgetItem *);
 
+signals:
+    void lvMenuRequested(QTreeWidgetItem *item);
+
 };
 
 #endif
